@@ -3,7 +3,7 @@
 %%
 %% SPDX-License-Identifier: Apache-2.0
 %%
-%% Copyright Ericsson AB 2004-2026. All Rights Reserved.
+%% Copyright Ericsson AB 2004-2025. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -416,8 +416,7 @@ handle_kexinit_msg(#ssh_msg_kexinit{} = CounterPart, #ssh_msg_kexinit{} = Own,
             ?DISCONNECT(?SSH_DISCONNECT_KEY_EXCHANGE_FAILED, Msg)
         end;
 
-handle_kexinit_msg(#ssh_msg_kexinit{first_kex_packet_follows = CounterGuess} = CounterPart,
-                   #ssh_msg_kexinit{} = Own,
+handle_kexinit_msg(#ssh_msg_kexinit{} = CounterPart, #ssh_msg_kexinit{} = Own,
                    #ssh{role = server} = Ssh, ReNeg) ->
     try
         {ok, Algorithms} =
@@ -427,8 +426,7 @@ handle_kexinit_msg(#ssh_msg_kexinit{first_kex_packet_follows = CounterGuess} = C
         Algorithms
     of
 	Algos ->
-            IsGuessWrong = is_guess_wrong(CounterGuess, CounterPart, Own),
-            {ok, Ssh#ssh{algorithms = Algos, ignore_initial_kex_message = IsGuessWrong}}
+            {ok, Ssh#ssh{algorithms = Algos}}
     catch
         Class:Reason0 ->
             Reason = ssh_lib:trim_reason(Reason0),
@@ -436,18 +434,6 @@ handle_kexinit_msg(#ssh_msg_kexinit{first_kex_packet_follows = CounterGuess} = C
             ?DISCONNECT(?SSH_DISCONNECT_KEY_EXCHANGE_FAILED, Msg)
     end.
 
-%% RFC 4253 section 7 check if guess is wrong
-is_guess_wrong(false, _, _) ->
-    false;
-is_guess_wrong(true,
-               #ssh_msg_kexinit{kex_algorithms = [Kex | _],
-                                server_host_key_algorithms = [HKey | _]},
-               #ssh_msg_kexinit{kex_algorithms = [Kex | _],
-                                server_host_key_algorithms = [HKey | _]}) ->
-    false;
-is_guess_wrong(true, _, _) ->
-    true.
-
 kexinit_error(Class, Error, Role, Own, CounterPart, Ssh) ->
     {Fmt,Args} =
         case {Class,Error} of
